from streamlit.errors import StreamlitAPIException


def _type_error(param, name, expected):
    """Format a string with markdown syntax to describe a type error."""
    format_exp = ""
    first = True
    for exp in expected:
        if first:
            first = False
        else:
            format_exp += " or "
        format_exp += f"*{exp}*"

    return (
        f"The {name} parameter from st_navbar() received an invalid type.\n"
        f"\nExpected: {format_exp}  "
        f"\nGot: *{type(param).__name__}*"
    )


def _dict_error(param, name, case, value_expected):
    """Format a string with markdown syntax to describe a dictionary error."""
    if case == "key":
        got = f"{type(param).__name__}: {value_expected}"
    elif case == "value":
        got = f"str: {type(param).__name__}"

    return (
        f"The {name} parameter from st_navbar() received a dictionary that "
        f"has a {case} with an invalid type.\n"
        f"\nExpected: *dict of str: {value_expected}*  "
        f"\nGot: *dict of {got}*"
    )


def check_pages(pages):
    """Check if `pages` has a valid type and the minimum length required."""
    if not isinstance(pages, list):
        raise StreamlitAPIException(_type_error(pages, "pages", ["list"]))

    if not len(pages) > 0:
        raise StreamlitAPIException(
            "The pages parameter from st_navbar() received a list with an "
            "invalid length. The length must be larger than or equal to one.\n"
            "\nExpected: *len*(pages) >= 1  "
            f"\nGot: *len*(pages) == {len(pages)}"
        )

    for page in pages:
        if not isinstance(page, str):
            i = pages.index(page)
            raise StreamlitAPIException(
                "The pages parameter from st_navbar() received a list that "
                "has an item with an invalid type.\n"
                f"\nExpected: *type*(pages[{i}]) == *str*  "
                f"\nGot: *type*(pages[{i}]) == *{type(page).__name__}*"
            )


def check_selected(selected, logo_page, logo_path, pages):
    """Check if `selected` has a valid type and value."""
    sentinel = object()
    if selected is None or type(selected) == object:
        return

    if not isinstance(selected, str):
        raise StreamlitAPIException(
            _type_error(selected, "selected", ["str", "None"])
        )

    if selected not in pages:
        if selected != logo_page:
            raise StreamlitAPIException(
                "The selected parameter from st_navbar() received an invalid "
                "value. The value must be contained in the pages parameter list "
                "or be equal to the logo_page (if there is a logo).\n"
                f"\nExpected: selected in pages or selected == logo_page  "
                f"\nGot: '{selected}' not in {pages} and '{selected}' != "
                f"'{logo_page}'"
            )

        if selected == logo_page and logo_path is None:
            raise StreamlitAPIException(
                "The selected parameter from st_navbar() received an invalid "
                "value. If the value is not contained in the pages parameter "
                "list, and it is equal to the logo_page, it must have a valid "
                "logo_path that is different than None."
            )


def check_logo_path(logo_path):
    """Check if `logo_path` has a valid type."""
    if not isinstance(logo_path, str) and logo_path is not None:
        raise StreamlitAPIException(
            _type_error(logo_path, "logo_path", ["str", "None"])
        )


def check_logo_page(logo_page):
    """Check if `logo_page` has a valid type."""
    if not isinstance(logo_page, str) and logo_page is not None:
        raise StreamlitAPIException(
            _type_error(logo_page, "logo_page", ["str", "None"])
        )


def check_urls(urls, pages):
    """Check if `urls` has types and pages that are valid."""
    if urls is None:
        return

    if not isinstance(urls, dict):
        raise StreamlitAPIException(
            _type_error(urls, "urls", ["dict", "None"])
        )

    if len(urls) > len(pages):
        raise StreamlitAPIException(
            "The urls parameter from st_navbar() received a dictionary with "
            "an invalid length. The length must be smaller than or equal to "
            "the list length of the pages parameter.\n"
            f"\nExpected: *len*(urls) <= {len(pages)}  "
            f"\nGot: *len*(urls) = {len(urls)}"
        )

    for page, url in urls.items():
        if not isinstance(page, str):
            raise StreamlitAPIException(
                _dict_error(page, "urls", "key", "str")
            )

        if page not in pages:
            raise StreamlitAPIException(
                "The urls parameter from st_navbar() received a dictionary "
                "that has an invalid key. The key must be contained in the "
                "pages parameter list.\n"
                f"\nExpected: urls key in pages  "
                f"\nGot: '{page}' not in {pages}"
            )

        if not isinstance(url, str):
            raise StreamlitAPIException(
                _dict_error(url, "urls", "value", "str")
            )


def check_styles(styles):
    """Check if `styles` has types and targets that are valid."""
    if styles is None:
        return

    if not isinstance(styles, dict):
        raise StreamlitAPIException(
            _type_error(styles, "styles", ["dict", "None"])
        )

    for target, style in styles.items():
        if not isinstance(target, str):
            raise StreamlitAPIException(
                _dict_error(target, "styles", "key", "dict")
            )

        targets = [
            "nav", "div", "ul", "li", "a", "img", "span", "active", "hover"
        ]
        if target not in targets:
            raise StreamlitAPIException(
                "The styles parameter from st_navbar() received a dictionary "
                "that has an invalid key. The key must be one of the "
                "available HTML tags or pseudo-classes.\n"
                f"\nExpected: 'nav', 'div', 'ul', 'li', 'a', 'img', 'span', "
                "'active', 'hover'  "
                f"\nGot: '{target}'"
            )

        if not isinstance(style, dict):
            raise StreamlitAPIException(
                _dict_error(style, "styles", "value", "dict")
            )

        for css_property, value in style.items():
            if not isinstance(css_property, str):
                raise StreamlitAPIException(
                    _dict_error(css_property, "styles", "key", "str")
                )

            if not isinstance(value, str):
                raise StreamlitAPIException(
                    _dict_error(value, "styles", "value", "str")
                )


def check_options(options):
    """Check if `options` has types, keys and values that are valid."""
    if isinstance(options, bool):
        return

    if not isinstance(options, dict):
        raise StreamlitAPIException(
            _type_error(options, "options", ["bool", "dict"])
        )

    for option, toggle in options.items():
        if not isinstance(option, str):
            raise StreamlitAPIException(
                _dict_error(option, "options", "key", "bool")
            )

        available = ["show_menu", "show_sidebar", "fix_shadow"]
        if option not in available:
            raise StreamlitAPIException(
                "The adjust parameter from st_navbar() received a "
                "dictionary that has an invalid key. The key must be the name "
                "of one of the available options.\n"
                f"\nExpected: 'show_menu', 'show_sidebar', 'fix_shadow'  "
                f"\nGot: '{option}'"
            )

        if not isinstance(toggle, bool):
            raise StreamlitAPIException(
                _dict_error(toggle, "options", "value", "bool")
            )


def check_adjust(adjust):
    """Check if `adjust` has a valid type."""
    if not isinstance(adjust, bool):
        raise StreamlitAPIException(
            _type_error(adjust, "adjust", ["bool"])
        )


def check_key(key):
    """Check if `key` has a valid type."""
    if not isinstance(key, str) and not isinstance(key, int) and key is not None:
        raise StreamlitAPIException(
            _type_error(key, "key", ["str", "int", "None"])
        )



from streamlit.config import get_config_options
from streamlit_theme import st_theme


class MatchNavbar():
    """
    Represent a user interface object with a style that matches the navbar.

    Attributes
    ----------
    configs : dict of {str : str}
        A dictionary that maps CSS variables to theme variables names, which
        are also config options.
    styles : dict of {str : {dict of {str : str}}
        A dictionary with the HTML tag or pseudo-class name as the key and
        another dictionary to style it as the value. In the second dictionary,
        the key-value pair is the name of a CSS property and the value it
        takes. The keys and values must be strings.
    key : str, int or None
        A key associated with the container that gets the theme. This needs to
        be unique since all styles will be applied to the container with this
        key.

    Methods
    -------
    get_value(css_property, targets, default, theme_config=None)
        Get the value of a CSS property.
    """

    configs = {
        "var(--primary-color)": "primaryColor",
        "var(--background-color)": "backgroundColor",
        "var(--secondary-background-color)": "secondaryBackgroundColor",
        "var(--text-color)": "textColor",
        "var(--font)": "font",
    }

    def __init__(self, styles, key):
        """
        Instantiate a user interface object to get CSS that matches the navbar.

        Parameters
        ----------
        styles : dict of {str : {dict of {str : str}}
            A dictionary with the HTML tag or pseudo-class name as the key and
            another dictionary to style it as the value. In the second
            dictionary, the key-value pair is the name of a CSS property and
            the value it takes. The keys and values must be strings.
        key : str, int or None
            A key associated with the container that gets the theme. This needs
            to be unique since all styles will be applied to the container with
            this key.
        """
        self.styles = styles
        self.theme = st_theme(key=f"key_{key}")

    def _get_theme_config(self, theme_configs):
        """
        Get the value of a CSS property from the theme or config option.

        Try to find the value with the name at the beginning of the list.
        Search first in the frontend theme object and then in the configuration
        options. In case it does not find it, iterates to the next name.
        Whenever the value is found it is returned immediately. If at the end
        it is still not found, returns ``None``.

        Parameters
        ----------
        theme_configs : list of str
            A list with the names of the frontend theme variables, which are
            also Streamlit's configuration options, to get the value from.

        Returns
        -------
        value : str or None
            The value of the CSS property found in `styles`, `theme` or config
            options. If not found, returns ``None``.
        """
        theme = self.theme
        configs = self.configs.values()

        # Get the value for the var in `styles`, then, for the `theme_config`.
        for theme_config in theme_configs:

            # Return the CSS value from `theme`.
            if theme is not None and theme_config in theme:
                return theme[theme_config]

            # Return the CSS value from configs, like a TOML file.
            if theme_config in configs:
                value = get_config_options()[f"theme.{theme_config}"].value
                if value is not None:
                    return value
        
        # Not found.
        return None

    def _get_style(self, css_property, targets):
        """
        Get the value of a CSS property from a styles dictionary.

        Try to find the value with the target at the beginning of the list. In
        case it does not find it, iterates to the next target. Whenever the
        value is found it is returned immediately. If at the end it is still
        not found, returns ``None``.

        The value found and returned will be either a plain CSS value, or the
        name of a theme variable and config option, which the
        `_get_theme_config` function will get its value later.

        Parameters
        ----------
        css_property : str
            The name of the CSS property to get the value from.
        targets : list of str
            A list with the targets where to look up the CSS property value in
            the styles dictionary. It tries to find with the first target,
            if it does not find it, it iterates to the next ones.

            The available targets are: ``"nav"``, ``"div"``, ``"ul"``,
            ``"li"``, ``"a"``, ``"img"``, ``"span"``, ``"active"`` and
            ``"hover"``.

        Returns
        -------
        value : str or None
            The value of the CSS property or the name of the theme variable and
            config option, found in `styles`. If not found, returns ``None``.
        """
        styles = self.styles
        configs = self.configs

        # Search for the CSS value in `styles`.
        for target in targets:
            if target in styles and css_property in styles[target]:
                value = styles[target][css_property]

                # Return a plain value.
                if value not in configs:
                    return value

                # Return `var(--theme-variable)` changed to `themeVariable`.
                return configs[value]

        # Not found.
        return None

    def get_value(self, css_property, targets, default, theme_config=None):
        """
        Get the value of a CSS property.

        Search for the value to style Streamlit's header and UI elements, e.g.
        menu and sidebar buttons, seamlessly with the navbar.

        It tries to first find it in the styles dictionary, then in the
        frontend theme object and finally in the configuration options. When it
        does not find with the first method, it goes to the next one in the
        sequence. Whenever the value is found it is returned immediately. If at
        the end it is still not found, returns a default value.

        Parameters
        ----------
        css_property : str
            The name of the CSS property to get the value from.
        targets : list of str
            A list with the targets where to look up the CSS property value in
            the styles dictionary. It tries to find with the first target, if
            it does not find it, it iterates to the next ones.

            The available targets are: ``"nav"``, ``"div"``, ``"ul"``,
            ``"li"``, ``"a"``, ``"img"``, ``"span"``, ``"active"`` and
            ``"hover"``.
        default : str
            The default value to be returned, in case the CSS property is not
            found in `styles`, `theme` or config options.
        theme_config : str, optional
            The name of the frontend theme variable, which is also Streamlit's
            configuration option, to get the value from. Defauls to ``None``,
            where the function does not go through the theme and configuration
            steps in the search sequence.

        Returns
        -------
        value : str
            The value of the CSS property found in `styles`, `theme`, config
            options or a default.
        """
        configs = self.configs.values()
        value = None
        theme_configs = []

        if self.styles is not None:
            value = self._get_style(css_property, targets)

        # Return plain value found in `styles`.
        if value is not None and value not in configs:
            return value

        # Not found in `styles` and no need to search in `theme` or configs.
        if value is None and theme_config is None:
            return default

        # Theme variable and config option found in `styles`.
        if value in configs:
            theme_configs.append(value)

        theme_configs.append(theme_config)
        value = self._get_theme_config(theme_configs)

        # Not found, return the default.
        if value is None:
            return default

        return value



import os
import base64

import streamlit as st
import streamlit.components.v1 as components
from jinja2 import FileSystemLoader, Environment

from streamlit_navigation_bar.match_navbar import MatchNavbar
from streamlit_navigation_bar.errors import (
    check_pages,
    check_selected,
    check_logo_path,
    check_logo_page,
    check_urls,
    check_styles,
    check_options,
    check_adjust,
    check_key,
)


_RELEASE = True

if not _RELEASE:
    _st_navbar = components.declare_component(
        "st_navbar",
        url="http://localhost:5173",
    )
else:
    parent_dir = os.path.dirname(os.path.abspath(__file__))
    build_dir = os.path.join(parent_dir, "frontend/dist")
    _st_navbar = components.declare_component(
        "st_navbar",
        path=build_dir,
    )


def _encode_svg(path):
    """Encode an SVG to base64, from an absolute path."""
    svg = open(path).read()
    return base64.b64encode(svg.encode("utf-8")).decode("utf-8")


def _prepare_urls(urls, pages):
    """Build dict with targets, given hrefs and defaults where omitted."""
    if urls is None:
        urls = {}
    for page in pages:
        if page in urls:
            urls[page] = [urls[page], "_blank"]
        else:
            urls[page] = ["#", "_self"]
    return urls


def _prepare_options(options):
    """Build dict with given options, state and defaults where omitted."""
    available = {
        "show_menu": True,
        "show_sidebar": True,
        "fixed_shadow": True,
    }
    for option in available:
        if isinstance(options, dict) and option in options:
            available[option] = options[option]
        elif isinstance(options, bool) and not options:
            available[option] = options
    return available


def _adjust(css):
    """Apply a CSS adjustment."""
    wrapped = "<style>" + css + "</style>"
    st.markdown(wrapped, unsafe_allow_html=True)


def get_path(directory):
    """Get the abs path for a directory in the same location as this file."""
    parent_dir = os.path.dirname(os.path.abspath(__file__))
    return os.path.join(parent_dir, directory)


def load_env(path):
    """Load the Jinja environment from a given absolute path."""
    loader = FileSystemLoader(path)
    return Environment(loader=loader, trim_blocks=True, lstrip_blocks=True)


def stylized_container(key):
    """
    Add a spaceless container to the app.

    Insert a container into the app, which receives an iframe that does not
    render anything. Style this container using CSS and a unique key to remove
    the space added by Streamlit.

    Parameters
    ----------
    key : str, int or None
        A key associated with this container. This needs to be unique since all
        styles will be applied to the container with this key.

    Returns
    -------
    container : DeltaGenerator
        A container object. Elements can be added to this container using
        either the "with" notation or by calling methods directly on the
        returned object.
    """
    html = (
        f"""
        <style>
            div[data-testid='stVerticalBlock']:has(
                > div.element-container
                > div.stMarkdown
                > div[data-testid='stMarkdownContainer']
                > p
                > span.{key}
            ) > div:first-child {{
                margin-bottom: -1rem;
            }}
        </style>
        <span class='{key}'></span>
        """
    )
    container = st.container()
    container.markdown(html, unsafe_allow_html=True)
    return container


def adjust_css(styles, options, key, path):
    """
    Apply CSS adjustments to display the navbar correctly.

    By default, Streamlit limits the position of components in the web app to
    a certain width and adds a padding to the top. This function renders Jinja
    templates to adjust the CSS and display the navbar at the full width at the
    top of the window, among other options that can be toggled on or off.

    It also matches the style, theme and configuration between the navbar and 
    Streamlit's User Interface (UI) elements, to make them look seamless.

    Parameters
    ----------
    styles : dict of {str : {dict of {str : str}}
        Apply CSS styles to desired targets, through a dictionary with the HTML
        tag or pseudo-class name as the key and another dictionary to style it
        as the value. In the second dictionary, the key-value pair is the name
        of a CSS property and the value it takes. The keys and values must be
        strings.

        The available HTML tags are: ``"nav"``, ``"div"``, ``"ul"``, ``"li"``,
        ``"a"``, ``"img"`` and ``"span"``.

        The available pseudo-classes are: ``"active"`` and ``"hover"``, which
        direct the styling to the ``"span"`` tag. The menu and sidebar buttons
        are only styled by ``"hover"`` (if they are set to ``True`` in
        `options`). Currently, ``"hover"`` only accepts two CSS properties, they
        are: ``"color"`` and ``"background-color"``.
    options : bool or dict of {str : bool}
        Customize the navbar with options that can be toggled on or off. It
        accepts a dictionary with the option name as the key and a boolean as
        the value. The available options are: ``"show_menu"``,
        ``"show_sidebar"`` and ``"fix_shadow"``.

        It is also possible to toggle all options to the same state. Simply
        pass ``True`` or ``False`` to `options`.
    key : str, int or None
        A key associated with the container that adjusts the CSS. This needs to
        be unique since all styles will be applied to the container with this
        key.
    path : str
        The absolute path to the directory containing the Jinja templates with
        the CSS adjustments.
    """
    ui = MatchNavbar(styles, key)

    ui.height = ui.get_value(
        css_property="height",
        targets=["nav"],
        default="2.875rem",
    )
    ui.hover_bg_color = ui.get_value(
        css_property="background-color",
        targets=["hover"],
        default="transparent",
    )
    ui.color = ui.get_value(
        css_property="color",
        targets=["span"],
        default="rgb(49, 51, 63)",
        theme_config="textColor",
    )
    ui.bg_color = ui.get_value(
        css_property="background-color",
        targets=["nav"],
        default="rgb(240, 242, 246)",
        theme_config="secondaryBackgroundColor",
    )
    ui.hover_color = ui.get_value(
        css_property="color",
        targets=["hover", "span"],
        default="rgb(49, 51, 63)",
        theme_config="textColor",
    )

    options = _prepare_options(options)
    margin = options["show_menu"] or options["show_sidebar"]
    key = f"st_navbar_key_{key}"

    env = load_env(path)
    template = env.get_template("options.css")
    css = template.render(
        ui=ui,
        options=options,
        margin=margin,
        key=key,
    )
    with stylized_container(key):
        _adjust(css)


# A placeholder object to implement the default rules for selected
sentinel = object()


def st_navbar(
    pages,
    selected=sentinel,
    logo_path=None,
    logo_page="Home",
    urls=None,
    styles=None,
    options=True,
    adjust=True,
    key=None,
):
    """
    Place a navigation bar in your Streamlit app.
    
    If there is no ``st.set_page_config`` command on the app page,
    ``st_navbar`` must be the first Streamlit command used, and must only be
    set once per page. If there is a ``st.set_page_config`` command, then
    ``st_navbar`` must be the second one, right after it.

    Parameters
    ----------
    pages : list of str
        A list with the name of each page that will be displayed in the
        navigation bar.
    selected : str or None, optional
        The preselected page on first render. It can be a name from `pages`,
        the `logo_page` (when there is a logo) or ``None``. Defaults to the
        `logo_page` value, if there is a logo. In case there is not one,
        defaults to the first page of the `pages` list. When set to ``None``,
        it will initialize empty and return ``None`` until the user selects a
        page.
    logo_path : str, optional
        The absolute path to an SVG file for a logo. It will be shown on the
        left side of the navigation bar. Defaults to ``None``, where no logo is
        displayed.
    logo_page : str or None, default="Home"
        The page value that will be returned when the logo is selected, if
        there is one. Defaults to ``"Home"``. For a non-clickable logo, set
        this to ``None``.
    urls : dict of {str : str}, optional
        A dictionary with the page name as the key and an external URL as the
        value, both as strings. The page name must be contained in the `pages`
        list. The URL will open in a new window or tab. The default is
        ``None``.
    styles : dict of {str : {dict of {str : str}}, optional
        Apply CSS styles to desired targets, through a dictionary with the HTML
        tag or pseudo-class name as the key and another dictionary to style it
        as the value. In the second dictionary, the key-value pair is the name
        of a CSS property and the value it takes. The keys and values must be
        strings. Defaults to ``None``, where no custom style is applied.

        The available HTML tags are: ``"nav"``, ``"div"``, ``"ul"``, ``"li"``,
        ``"a"``, ``"img"`` and ``"span"``. To better understand the Document
        Object Model, check the notes section.

        The available pseudo-classes are: ``"active"`` and ``"hover"``, which
        direct the styling to the ``"span"`` tag. The menu and sidebar buttons
        are only styled by ``"hover"`` (if they are set to ``True`` in
        `options`). Currently, ``"hover"`` only accepts two CSS properties,
        they are: ``"color"`` and ``"background-color"``.
    options : bool or dict of {str : bool}, default=True
        Customize the navbar with options that can be toggled on or off. It
        accepts a dictionary with the option name as the key and a boolean as
        the value. The available options are: ``"show_menu"``,
        ``"show_sidebar"`` and ``"fix_shadow"``. Check the notes section for a
        description of each one.

        It is also possible to toggle all options to the same state. Simply
        pass ``True`` to `options`, which is the parameter default value, or
        ``False``.
    adjust : bool, default=True
        When set to ``True`` (default), it overrides some Streamlit behaviors
        and makes a series of CSS adjustments to display the navbar correctly.

        In most cases, the CSS adjustments do not interfere with the rest of
        the web app, however there could be some situations where this occurs.
        If this happens, or it is desired to disable all of them, pass
        ``False`` to `adjust` and, when necessary, make your own CSS
        adjustments with ``st.markdown``.

        If set to ``False``, it will also disable all adjustments made by
        `options`, regardless of whether they are on or off.
    key : str or int, optional
        A string or integer to use as a unique key for the component. Multiple
        navbars may not share the same key. Defaults to ``None``.

    Returns
    -------
    page : str or None
        The page selected by the user. If there has been no interaction yet,
        returns the preselected page or ``None``.

    Notes
    -----
    **CSS variables**

    The component accepts theme configuration options to be passed as CSS
    variables in the `styles` dictionary, for example::
    
        styles = {
            "nav": {
                "background-color": "var(--primary-color)"
            }
        }
    
    The CSS variables that can be used are::
    
        --primary-color
        --background-color
        --secondary-background-color
        --text-color
        --font

    By default, the navbar uses in the following targets these CSS variables::
    
        styles = {
            "nav": {
                "font-family": "var(--font)",
                "background-color": "var(--secondary-background-color)"
            },
            "span": {
                "color": "var(--text-color)"
            },
            "active": {
                "color": "var(--text-color)"
            }
        }
    
    They can be overridden by simply passing another value to the respective
    target and CSS property in `styles`.

    **Document Object Model**
    
    To style the navigation bar, it is important to understand its Document
    Object Model (DOM). For example, if a navbar is created with
    ``pages=["Hello, World!"]`` and an SVG logo. On the frontend side, the
    component builds this DOM (simplified for readability)::

        <nav>
          <div>
            <ul>
              <li>
                <a>
                  <img src="svg_logo" img/>
                </a>
              </li>
              <li>
                <a>
                  <span>
                    Hello, World!
                  </span>
                </a>
              </li>
            </ul>
          </div>
        </nav>

    Notice that the ``"a"`` tag will style both the logo and the page name.
    However, the ``"img"`` tag is unique to the logo, just as ``"span"`` is to
    the page names.

    **Maximum width**

    A fundamental CSS property to adjust is the ``"max-width"`` for the
    ``"div"`` tag. Because it controls how much space the page names have
    between them. The default value is ``"700px"``, which works well
    in most cases. But if the navbar has a large number of pages, or longer
    names, it might be necessary to increase the maximum width. Conversely,
    whenever the navbar has few pages or short names, this value may need to
    be reduced.

    **Options**

    The available options and their descriptions are:

    "show_menu"
        Show Streamlit's menu button in the navbar.
    "show_sidebar"
        Show Streamlit's sidebar button in the navbar. However, it is still
        needed to use ``st.sidebar`` in the app, in order for the sidebar
        button to properly appear. Just like Streamlit's default behavior.
    "fix_shadow"
        Fix the shadow of the expanded sidebar, showing it no matter the window
        width. It is useful when the navbar and the sidebar have the same
        background color, which they do by default, because the shadow makes it
        possible to differentiate between the two elements.

        When set to ``False``, it assumes Streamlit's default behavior, where
        it applies the shadow only when the window width is below a certain
        threshold.

    Examples
    --------
    >>> import streamlit as st
    >>> from streamlit_navigation_bar import st_navbar
    >>> page = st_navbar(
    ...     ["Home", "Documentation", "Examples", "Community", "About"]
    ... )
    >>> st.write(page)

    .. output::
           https://st-navbar-1.streamlit.app/
           height: 300px
    """
    check_pages(pages)
    check_selected(selected, logo_page, logo_path, pages)
    check_logo_path(logo_path)
    check_logo_page(logo_page)
    check_urls(urls, pages)
    check_styles(styles)
    check_options(options)
    check_adjust(adjust)
    check_key(key)

    if selected is sentinel:
        if logo_path is not None:
            default = logo_page
        else:
            default = pages[0]
    else:
        default = selected

    base64_svg = None
    if logo_path is not None:
        base64_svg = _encode_svg(logo_path)

    urls = _prepare_urls(urls, pages)

    page = _st_navbar(
        pages=pages,
        default=default,
        base64_svg=base64_svg,
        logo_page=logo_page,
        urls=urls,
        styles=styles,
        key=key,
    )

    if adjust:
        adjust_css(styles, options, key, get_path("templates"))

    return page



import os

import streamlit as st

from streamlit_navigation_bar import st_navbar


st.set_page_config(initial_sidebar_state="collapsed")

pages = ["Documentation", "Examples", "Community", "GitHub"]
parent_dir = os.path.dirname(os.path.abspath(__file__))
logo_path = os.path.join(parent_dir, "logo.svg")
urls = {"GitHub": "https://github.com"}
styles = {
    "nav": {"background-color": "var(--primary-color)"},
    "span": {"color": "white"},
}
options = {"show_sidebar": False}

page = st_navbar(
    pages,
    logo_path=logo_path,
    urls=urls,
    styles=styles,
    options=options,
)
st.write(page)

with st.sidebar:
    st.write("The sidebar button will not be shown.")
